Crate trs_mlflow

Crate trs_mlflow 

This crate contains an unofficial asynchronous mlflow client which uses 2.0 API.

The whole API description can be found here: https://mlflow.org/docs/latest/rest-api.html

Usage example:

use trs_mlflow::{run::CreateRun, Client};

let client = Client::new("http://localhost:5000/api");

let experiment_id = client
    .create_experiment(&"foo", vec![])
    .await
    .expect("BUG: Cannot create experiment");

let create = CreateRun::new()
    .run_name("bar")
    .experiment_id(&experiment_id)
    .build();

let run = client
    .create_run(create)
    .await
    .expect("BUG: Cannot create run");

Testing

If you want to run tests you need to run MlFlow server locally, which can be done by running this command:

./server/run.sh

This command creates a new venv, installs server and then runs it.

Disclaimer

This is heavy WIP crate as I’m still trying to figure out how to wrap some API methods.

Modules

artifact
Contains everything that is related model artifacts.
config
This module contains client configuration.
experiment
Contains everything related to experiments.
modelversion
Contains everything related to model versioning.
registered
Contains structures which are used in manage registered models.
run
Contains everything that is related to mlflow run.

Structs

Client
This is low-level client which reflects mlflow 2.0 API.